==> huaweicloudsdkdbss-3.1.135-py2.py3-none-any.whl: huaweicloudsdkdbss/v1/model/list_audit_agent_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAuditAgentRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'db_id': 'str',
        'offset': 'str',
        'limit': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'db_id': 'db_id',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, instance_id=None, db_id=None, offset=None, limit=None):
        """ListAuditAgentRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID。可在查询实例列表接口的ID字段获取。
        :type instance_id: str
        :param db_id: 数据库ID,可在查询数据库列表接口ID字段获取。
        :type db_id: str
        :param offset: 偏移量
        :type offset: str
        :param limit: 查询记录数
        :type limit: str
        """
        
        

        self._instance_id = None
        self._db_id = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.instance_id = instance_id
        self.db_id = db_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def instance_id(self):
        """Gets the instance_id of this ListAuditAgentRequest.

        实例ID。可在查询实例列表接口的ID字段获取。

        :return: The instance_id of this ListAuditAgentRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this ListAuditAgentRequest.

        实例ID。可在查询实例列表接口的ID字段获取。

        :param instance_id: The instance_id of this ListAuditAgentRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def db_id(self):
        """Gets the db_id of this ListAuditAgentRequest.

        数据库ID,可在查询数据库列表接口ID字段获取。

        :return: The db_id of this ListAuditAgentRequest.
        :rtype: str
        """
        return self._db_id

    @db_id.setter
    def db_id(self, db_id):
        """Sets the db_id of this ListAuditAgentRequest.

        数据库ID,可在查询数据库列表接口ID字段获取。

        :param db_id: The db_id of this ListAuditAgentRequest.
        :type db_id: str
        """
        self._db_id = db_id

    @property
    def offset(self):
        """Gets the offset of this ListAuditAgentRequest.

        偏移量

        :return: The offset of this ListAuditAgentRequest.
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this ListAuditAgentRequest.

        偏移量

        :param offset: The offset of this ListAuditAgentRequest.
        :type offset: str
        """
        self._offset = offset

    @property
    def limit(self):
        """Gets the limit of this ListAuditAgentRequest.

        查询记录数

        :return: The limit of this ListAuditAgentRequest.
        :rtype: str
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this ListAuditAgentRequest.

        查询记录数

        :param limit: The limit of this ListAuditAgentRequest.
        :type limit: str
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAuditAgentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdbss-3.1.155-py2.py3-none-any.whl: huaweicloudsdkdbss/v1/model/list_audit_agent_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListAuditAgentRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'db_id': 'str',
        'offset': 'str',
        'limit': 'str'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'db_id': 'db_id',
        'offset': 'offset',
        'limit': 'limit'
    }

    def __init__(self, instance_id=None, db_id=None, offset=None, limit=None):
        r"""ListAuditAgentRequest

        The model defined in huaweicloud sdk

        :param instance_id: 实例ID。可在查询实例列表接口的ID字段获取。
        :type instance_id: str
        :param db_id: 数据库ID,可在查询数据库列表接口ID字段获取。
        :type db_id: str
        :param offset: 偏移量
        :type offset: str
        :param limit: 查询记录数
        :type limit: str
        """
        
        

        self._instance_id = None
        self._db_id = None
        self._offset = None
        self._limit = None
        self.discriminator = None

        self.instance_id = instance_id
        self.db_id = db_id
        if offset is not None:
            self.offset = offset
        if limit is not None:
            self.limit = limit

    @property
    def instance_id(self):
        r"""Gets the instance_id of this ListAuditAgentRequest.

        实例ID。可在查询实例列表接口的ID字段获取。

        :return: The instance_id of this ListAuditAgentRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        r"""Sets the instance_id of this ListAuditAgentRequest.

        实例ID。可在查询实例列表接口的ID字段获取。

        :param instance_id: The instance_id of this ListAuditAgentRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def db_id(self):
        r"""Gets the db_id of this ListAuditAgentRequest.

        数据库ID,可在查询数据库列表接口ID字段获取。

        :return: The db_id of this ListAuditAgentRequest.
        :rtype: str
        """
        return self._db_id

    @db_id.setter
    def db_id(self, db_id):
        r"""Sets the db_id of this ListAuditAgentRequest.

        数据库ID,可在查询数据库列表接口ID字段获取。

        :param db_id: The db_id of this ListAuditAgentRequest.
        :type db_id: str
        """
        self._db_id = db_id

    @property
    def offset(self):
        r"""Gets the offset of this ListAuditAgentRequest.

        偏移量

        :return: The offset of this ListAuditAgentRequest.
        :rtype: str
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        r"""Sets the offset of this ListAuditAgentRequest.

        偏移量

        :param offset: The offset of this ListAuditAgentRequest.
        :type offset: str
        """
        self._offset = offset

    @property
    def limit(self):
        r"""Gets the limit of this ListAuditAgentRequest.

        查询记录数

        :return: The limit of this ListAuditAgentRequest.
        :rtype: str
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        r"""Sets the limit of this ListAuditAgentRequest.

        查询记录数

        :param limit: The limit of this ListAuditAgentRequest.
        :type limit: str
        """
        self._limit = limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListAuditAgentRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
